@@ -12,7 +12,13 @@ class CouponsStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['updated_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'plan_model/coupons'
+    SORT_BY = 'created_at'
 
+    def __init__(self, config, state, catalog, client):
+        BaseChargebeeStream.__init__(self, config, state, catalog, client)
+        if self.config['item_model']:
+            self.SCHEMA = 'item_model/coupons'
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/coupons'.format(self.config.get('site'))
