@@ -12,6 +12,8 @@ class PlansStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['updated_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'plan_model/plans'
+    SORT_BY = None
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/plans'.format(self.config.get('site'))
